config

package
v0.0.0-...-1e18c51 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 14, 2019 License: GPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// EthereumJSONRPCURL is to connected to ethereum client
	EthereumJSONRPCURL string
	//MerchantKey for processing payment and writing facts in passport address
	MerchantKey string
	//PaymentProcessorAddress for calling refundPayment and processPayment method
	PaymentProcessorAddress string
)

Functions

func Parse

func Parse() error

Parse will parse all the flags into config variables

Types

This section is empty.

Jump to